@@ -1,10 +1,9 @@
-from ELM import *
-from RVFL import *
-from MLP import *
-from DTC import *
-from LR import *
-from KNN import *
-from plotComponents2D import *
+from .ELM import *
+from .RVFL import *
+from .MLP import *
+from .DTC import *
+from .LR import *
+from .KNN import *
 import matplotlib.pyplot as plt
 from sklearn.model_selection import train_test_split
 from sklearn.tree import DecisionTreeClassifier
